==> haskell-persistent-qq-2.12.0.7-36-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-GS0CfSzNCJoJVcVGoMJ7Zk
key:                  persistent-qq-2.12.0.7-GS0CfSzNCJoJVcVGoMJ7Zk
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  be3ab4f52f6963e7ab89a57dbb506072
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-GS0CfSzNCJoJVcVGoMJ7Zk
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-BYHDzrxzNUGCPYpRhhLZ4F
    mtl-2.2.2 persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.7-58-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-CoUo3S5v5k34u0toQXOxkF
key:                  persistent-qq-2.12.0.7-CoUo3S5v5k34u0toQXOxkF
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  9fb14914728a610bfd14040b2dc504d3
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-CoUo3S5v5k34u0toQXOxkF
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-H1foZcB9BupJXsFCQU2aBa
    mtl-2.2.2 persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
